@@ -6,6 +6,7 @@ import fnmatch
 from flowtool.style import echo, colors
 from flowtool.style import debug
 from flowtool_git.common import local_repo
+from flowtool_githooks.discovering import find_files_named_in_project
 
 import pytest
 
@@ -20,28 +21,6 @@ def run_pytest(*args):
     return errno
 
 
-IGNORE_RECURSIVE = set([
-    '.git', '.tox', '.cache', 'build', 'dist', 'test', 'tests', 'venv',
-])
-
-def find_pytest_configs(repo=None):
-    """ Find dirs with pytest compatible configs. """
-
-    look_for = set(['pytest.ini', 'tox.ini'])
-
-    if repo is None:
-        repo = local_repo()
-
-    def ignore_location(loc):
-        inside = loc.split(os.sep)
-        shall_ignore = IGNORE_RECURSIVE.intersection(inside)
-        return bool(shall_ignore)
-
-    for loc, _, files in os.walk(os.path.dirname(repo.git_dir)):
-        if look_for.intersection(files) and not ignore_location(loc):
-            yield loc
-
-
 def pytest_setup(cmd=None):
     """ Setup function for pytest hook(s). """
     if cmd == 'install':
@@ -50,13 +29,15 @@ def pytest_setup(cmd=None):
         pass
 
 
+PYTEST_CONFIGS = ['pytest.ini', 'tox.ini']
+
 
 @click.command()
 @click.argument('args', nargs=-1)
 def pytest_hook(args=()):
     """ Run pytest in discovered directories. """
 
-    locations = list(find_pytest_configs())
+    locations = list(find_files_named_in_project(PYTEST_CONFIGS))
     if not locations:
         return
     echo.bold(
